@@ -13,14 +13,13 @@ property such as 'NetworkingEnabled', or 'WirelessEnabled' etc. in
 # of the license.
 
 __author__ = 'Iftikhar Ahmad'
-__email__ = 'iftikhar.ahmad@canonical.com'
 __copyright__ = '(c) 2012 Canonical Ltd.'
-__license__ = 'LGPL 3+'
 
-import dbus
 import uuid
 import binascii
 
+import dbus
+
 from dbusmock import MOCK_IFACE
 import dbusmock
 
@@ -40,7 +39,8 @@ SYSTEM_BUS = True
 IS_OBJECT_MANAGER = True
 
 
-class NMState:
+# these really want to be dataclasses, but need to drop support for Python 3.6 for that
+class NMState:  # pylint: disable=too-few-public-methods
     '''Global state
 
     As per https://developer.gnome.org/NetworkManager/unstable/nm-dbus-types.html#NMState
@@ -55,7 +55,7 @@ class NMState:
     NM_STATE_CONNECTED_GLOBAL = 70
 
 
-class NMConnectivityState:
+class NMConnectivityState:  # pylint: disable=too-few-public-methods
     '''Connectvity state
 
     As per https://developer.gnome.org/NetworkManager/unstable/nm-dbus-types.html#NMConnectivityState
@@ -67,7 +67,7 @@ class NMConnectivityState:
     NM_CONNECTIVITY_FULL = 4
 
 
-class NMActiveConnectionState:
+class NMActiveConnectionState:  # pylint: disable=too-few-public-methods
     '''Active connection state
 
     As per https://developer.gnome.org/NetworkManager/unstable/nm-dbus-types.html#NMActiveConnectionState
@@ -79,7 +79,7 @@ class NMActiveConnectionState:
     NM_ACTIVE_CONNECTION_STATE_DEACTIVATED = 4
 
 
-class InfrastructureMode:
+class InfrastructureMode:  # pylint: disable=too-few-public-methods
     '''Infrastructure mode
 
     As per https://developer.gnome.org/NetworkManager/unstable/nm-dbus-types.html#NM80211Mode
@@ -97,7 +97,7 @@ class InfrastructureMode:
     }
 
 
-class DeviceState:
+class DeviceState:  # pylint: disable=too-few-public-methods
     '''Device states
 
     As per https://developer.gnome.org/NetworkManager/unstable/nm-dbus-types.html#NMDeviceState
@@ -117,7 +117,7 @@ class DeviceState:
     FAILED = 120
 
 
-class NM80211ApSecurityFlags:
+class NM80211ApSecurityFlags:  # pylint: disable=too-few-public-methods
     '''Security flags
 
     As per https://developer.gnome.org/NetworkManager/unstable/nm-dbus-types.html#NM80211ApSecurityFlags
@@ -142,7 +142,7 @@ class NM80211ApSecurityFlags:
     }
 
 
-class NM80211ApFlags:
+class NM80211ApFlags:  # pylint: disable=too-few-public-methods
     '''Device flags
 
     As per https://developer.gnome.org/NetworkManager/unstable/nm-dbus-types.html#NM80211ApFlags
@@ -181,7 +181,10 @@ def add_and_activate_connection(self, conn_conf, dev, ap):
     name = ap.rsplit('/', 1)[1]
     RemoveWifiConnection(self, dev, '/org/freedesktop/NetworkManager/Settings/' + name)
 
-    raw_ssid = ''.join([chr(byte) for byte in conn_conf["802-11-wireless"]["ssid"]])
+    try:
+        raw_ssid = ''.join([chr(byte) for byte in conn_conf["802-11-wireless"]["ssid"]])
+    except KeyError:
+        raw_ssid = dbusmock.get_object(ap).props['org.freedesktop.NetworkManager.AccessPoint']['Ssid'].decode()
     wifi_conn = dbus.ObjectPath(AddWiFiConnection(self, dev, name, raw_ssid, ""))
 
     active_conn = activate_connection(self, wifi_conn, dev, ap)
@@ -189,15 +192,15 @@ def add_and_activate_connection(self, conn_conf, dev, ap):
     return (wifi_conn, active_conn)
 
 
-def get_device_by_ip_iface(self, iface):
+def get_device_by_ip_iface(_self, iface):
     NM = dbusmock.get_object(MANAGER_OBJ)
     for dev_path in NM.GetDevices():
         dev_obj = dbusmock.get_object(dev_path)
         interface = dev_obj.Get(DEVICE_IFACE, 'Interface')
         if interface == iface:
             return dev_path
-    else:
-        return None
+
+    return None
 
 
 def set_networking_enabled(self, networking_enabled):
@@ -227,16 +230,16 @@ def load(mock, parameters):
                      'WirelessHardwareEnabled': parameters.get('WirelessHardwareEnabled', True),
                      'WwanEnabled': parameters.get('WwanEnabled', False),
                      'WwanHardwareEnabled': parameters.get('WwanHardwareEnabled', True)}
-    manager_methods = [('GetDevices', '', 'ao',
-                                      'ret = [k for k in objects.keys() if "/Devices" in k]'),
+    manager_methods = [('GetDevices', '', 'ao', 'ret = [k for k in objects.keys() if "/Devices" in k]'),
                        ('GetPermissions', '', 'a{ss}', 'ret = {}'),
-                       ('state', '', 'u', "ret = self.Get('%s', 'State')" % MANAGER_IFACE),
-                       ('CheckConnectivity', '', 'u', "ret = self.Get('%s', 'Connectivity')" % MANAGER_IFACE),
+                       ('state', '', 'u', f"ret = self.Get('{MANAGER_IFACE}', 'State')"),
+                       ('CheckConnectivity', '', 'u', f"ret = self.Get('{MANAGER_IFACE}', 'Connectivity')"),
                        ('ActivateConnection', 'ooo', 'o', "ret = self.activate_connection(self, args[0], args[1], args[2])"),
                        ('DeactivateConnection', 'o', '', "self.deactivate_connection(self, args[0])"),
-                       ('AddAndActivateConnection', 'a{sa{sv}}oo', 'oo', "ret = self.add_and_activate_connection("
-                                                    "self, args[0], args[1], args[2])"),
+                       ('AddAndActivateConnection', 'a{sa{sv}}oo', 'oo',
+                        'ret = self.add_and_activate_connection(self, args[0], args[1], args[2])'),
                        ('GetDeviceByIpIface', 's', 'o', 'ret = self.get_device_by_ip_iface(self, args[0])'),
+                       ('Reload', 'u', '', ''),
                        ('Enable', 'b', '', 'self.set_networking_enabled(self, args[0])')]
 
     mock.AddObject(MANAGER_OBJ,
@@ -255,7 +258,7 @@ def load(mock, parameters):
     settings_props = {'Hostname': 'hostname',
                       'CanModify': True,
                       'Connections': dbus.Array([], signature='o')}
-    settings_methods = [('ListConnections', '', 'ao', "ret = self.Get('%s', 'Connections')" % SETTINGS_IFACE),
+    settings_methods = [('ListConnections', '', 'ao', f"ret = self.Get('{SETTINGS_IFACE}', 'Connections')"),
                         ('GetConnectionByUuid', 's', 'o', 'ret = self.SettingsGetConnectionByUuid(args[0])'),
                         ('AddConnection', 'a{sa{sv}}', 'o', 'ret = self.SettingsAddConnection(args[0])'),
                         ('AddConnectionUnsaved', 'a{sa{sv}}', 'o', 'ret = self.SettingsAddConnection(args[0])'),
@@ -269,7 +272,7 @@ def load(mock, parameters):
 
 @dbus.service.method(MOCK_IFACE,
                      in_signature='sssv', out_signature='')
-def SetProperty(self, path, iface, name, value):
+def SetProperty(_self, path, iface, name, value):
     obj = dbusmock.get_object(path)
     obj.Set(iface, name, value)
     obj.EmitSignal(iface, 'PropertiesChanged', 'a{sv}', [{name: value}])
@@ -296,7 +299,7 @@ def SetNetworkingEnabled(self, networking_enabled):
 
 @dbus.service.method(MOCK_IFACE,
                      in_signature='ss', out_signature='')
-def SetDeviceActive(self, device_path, active_connection_path):
+def SetDeviceActive(_self, device_path, active_connection_path):
     dev_obj = dbusmock.get_object(device_path)
     dev_obj.Set(DEVICE_IFACE, 'ActiveConnection', dbus.ObjectPath(active_connection_path))
     old_state = dev_obj.Get(DEVICE_IFACE, 'State')
@@ -308,7 +311,7 @@ def SetDeviceActive(self, device_path, active_connection_path):
 
 @dbus.service.method(MOCK_IFACE,
                      in_signature='s', out_signature='')
-def SetDeviceDisconnected(self, device_path):
+def SetDeviceDisconnected(_self, device_path):
     dev_obj = dbusmock.get_object(device_path)
     dev_obj.Set(DEVICE_IFACE, 'ActiveConnection', dbus.ObjectPath('/'))
     old_state = dev_obj.Get(DEVICE_IFACE, 'State')
@@ -449,7 +452,7 @@ def AddAccessPoint(self, dev_path, ap_name, ssid, hw_address,
     ap_path = '/org/freedesktop/NetworkManager/AccessPoint/' + ap_name
     if ap_path in dev_obj.access_points:
         raise dbus.exceptions.DBusException(
-            'Access point %s on device %s already exists' % (ap_name, dev_path),
+            f'Access point {ap_name} on device {dev_path} already exists',
             name=MANAGER_IFACE + '.AlreadyExists')
 
     flags = NM80211ApFlags.NM_802_11_AP_FLAGS_PRIVACY
@@ -484,7 +487,7 @@ def AddAccessPoint(self, dev_path, ap_name, ssid, hw_address,
 
 @dbus.service.method(MOCK_IFACE,
                      in_signature='ssss', out_signature='s')
-def AddWiFiConnection(self, dev_path, connection_name, ssid_name, key_mgmt):
+def AddWiFiConnection(self, dev_path, connection_name, ssid_name, _key_mgmt):
     '''Add an available connection to an existing WiFi device and access point.
 
     You have to specify WiFi Device path, Connection object name,
@@ -517,7 +520,7 @@ def AddWiFiConnection(self, dev_path, connection_name, ssid_name, key_mgmt):
 
     if not access_point:
         raise dbus.exceptions.DBusException(
-            'Access point with SSID [%s] could not be found' % (ssid_name),
+            f'Access point with SSID [{ssid_name}] could not be found',
             name=MANAGER_IFACE + '.DoesNotExist')
 
     hw_address = access_point.Get(ACCESS_POINT_IFACE, 'HwAddress')
@@ -526,7 +529,7 @@ def AddWiFiConnection(self, dev_path, connection_name, ssid_name, key_mgmt):
 
     if connection_path in connections or connection_path in main_connections:
         raise dbus.exceptions.DBusException(
-            'Connection %s on device %s already exists' % (connection_name, dev_path),
+            f'Connection {connection_name} on device {dev_path} already exists',
             name=MANAGER_IFACE + '.AlreadyExists')
 
     # Parse mac address string into byte array
@@ -578,7 +581,7 @@ def AddWiFiConnection(self, dev_path, connection_name, ssid_name, key_mgmt):
     main_connections.append(connection_path)
     settings_obj.Set(SETTINGS_IFACE, 'Connections', main_connections)
 
-    settings_obj.EmitSignal(SETTINGS_IFACE, 'NewConnection', 'o', [ap_path])
+    settings_obj.EmitSignal(SETTINGS_IFACE, 'NewConnection', 'o', [ap_path])  # pylint: disable=undefined-loop-variable
 
     return connection_path
 
@@ -800,7 +803,7 @@ def SettingsGetConnectionByUuid(self, conn_uuid):
         settings = self.conn.GetSettings()
         if settings['connection']['uuid'] == conn_uuid:
             return o
-    raise dbus.exceptions.DBusException("There was no connection with uuid %s" % conn_uuid)
+    raise dbus.exceptions.DBusException(f"There was no connection with uuid {conn_uuid}")
 
 
 def ConnectionUpdate(self, settings):
@@ -818,7 +821,7 @@ def ConnectionUpdate(self, settings):
 
     if connection_path not in main_connections:
         raise dbus.exceptions.DBusException(
-            'Connection %s does not exist' % connection_path,
+            f'Connection {connection_path} does not exist',
             name=MANAGER_IFACE + '.DoesNotExist',)
 
     # Take care not to overwrite the secrets
